@@ -16,8 +16,9 @@
 #' @param rStack a \code{RasterStack} class argument containing a time series of
 #' satellite images. Layer names should contain the date of the image in
 #' "\code{YYYYJJJ}" format.
-#' @param Img2Fill a \code{vector} class argument defining the images to be 
+#' @param Img2Fill a \code{vector} argument defining the images to be 
 #' filled/smoothed.
+#' @param r.dates a \code{vector} argument containing the dates of the layers in rstack 
 #' @param nDays a \code{numeric} argument with the number of previous and 
 #' subsequent days that define the temporal neighborhood.
 #' @param nYears a \code{numeric} argument with the number of previous and 
@@ -33,7 +34,9 @@
 #' @param predictSE calculate the standard error instead the prediction.
 #' @param factSE the \code{fact} used in the standard error prediction.
 #' @param out.name the name of the folder containing the smoothed/filled images
-#' when saved in the Hard Disk Device (HDD). 
+#' when saved in the Hard Disk Device (HDD).
+#' @param only.na logical argument. If \code{TRUE} only fills the \code{NA} values. 
+#' \code{FALSE}  by default.
 #' @param ... arguments for nested functions:
 #' \itemize{
 #'   \item \code{AppRoot} the path where the filled/smoothed time series of
@@ -44,6 +47,7 @@
 #' 
 #' 
 #' @examples
+#' \dontrun{
 #' # load an example of NDVI time series in Navarre
 #' data(ex.ndvi.navarre)
 #' # the 2 images to be filled and the neighbourhood
@@ -51,20 +55,24 @@
 #'
 #' # filled images
 #' tiles.mod.ndvi.filled  <- genSmoothingIMA(ex.ndvi.navarre,
-#'                                Img2Fill = c(1,2))
+#'                                Img2Fill = c(1),
+#'                                only.na=TRUE)
 #' # show the filled images
 #' genPlotGIS(tiles.mod.ndvi.filled)
 #' # plot comparison of the cloud and the filled images
 #' tiles.mod.ndvi.comp <- stack(ex.ndvi.navarre[[1]], tiles.mod.ndvi.filled[[1]],
 #'                              ex.ndvi.navarre[[2]], tiles.mod.ndvi.filled[[2]])
 #' genPlotGIS(tiles.mod.ndvi.comp, layout=c(2, 2))
+#' }
 genSmoothingIMA<-function(rStack,
                           Img2Fill = NULL,
                           nDays = 3,
                           nYears = 1,
                           fact = 5,
                           fun=mean,
+                          r.dates,
                           aFilter = c(.05,.95),
+                          only.na = FALSE,
                           factSE=8,
                           predictSE=FALSE,
                           snow.mode=FALSE,
@@ -88,7 +96,15 @@ genSmoothingIMA<-function(rStack,
     if(length(aux)!=length(Img2Fill)){warning("Some of target images in Img2Fill do not exist in imgTS.")}
     Img2Fill<-aux
   }
-  alldates<-genGetDates(names(rStack))
+  if(!missing(r.dates)){
+    if(length(r.dates)!=nlayers(rStack))stop("r.dates and rStack must have the same length.")
+    alldates<-r.dates
+  }else{
+    alldates<-genGetDates(names(rStack))
+  }
+  
+  
+  
   if(all(is.na(alldates))){stop("The name of the layers has to include the date and it must be in julian days (%Y%j) .")}
   fillstack<-raster()
   for(i in Img2Fill){
@@ -99,6 +115,7 @@ genSmoothingIMA<-function(rStack,
     # define temporal neighbourhood
     neighbours<-dateNeighbours(ts.raster=rStack,
                                target.date=target.date,
+                               r.dates=alldates,
                                nPeriods=nDays,
                                nYears=nYears)
     message(paste0("   - Size of the neighbourhood: ",nlayers(neighbours)))
@@ -140,7 +157,11 @@ genSmoothingIMA<-function(rStack,
         target.prediction <- raster::interpolate(object=se.size, model=tps,fun=fields::predictSE)
       }
     }
-
+    
+    if(only.na){
+      targetImage[is.na(targetImage)]<-target.prediction[is.na(targetImage)]
+      target.prediction<-targetImage
+    }
     # write filled images
     if("AppRoot"%in%names(args)){
       writeRaster(target.prediction,paste0(args$AppRoot,"/",out.name,"/",format(target.date,"%Y%j"),".tif"))
@@ -159,6 +180,7 @@ genSmoothingIMA<-function(rStack,
 
 dateNeighbours<-function(ts.raster,
                          target.date,
+                         r.dates,
                          nPeriods=1,
                          nYears=1){
   targetyear<-as.integer(format(target.date,"%Y"))
@@ -167,7 +189,7 @@ dateNeighbours<-function(ts.raster,
   temporalYears<-(targetyear-nYears):(targetyear+nYears)
   temporalWindow<-paste0(rep(temporalYears,each=length(tempolarPeriods)),
                          rep(tempolarPeriods,length(temporalYears)))
-  return(raster::subset(ts.raster,which(format(genGetDates(names(ts.raster)),"%Y%j")%in%temporalWindow)))
+  return(raster::subset(ts.raster,which(format(r.dates,"%Y%j")%in%temporalWindow)))
 }
 
 MinSeg=function(fim, ini){
